@@ -45,10 +45,14 @@ class Fingerprint(GenericFingerprint):
         # Reference: https://dev.mysql.com/doc/relnotes/mysql/<major>.<minor>/en/
 
         versions = (
+            (90200, 90202),  # MySQL 9.2
+            (90100, 90102),  # MySQL 9.1
+            (90000, 90002),  # MySQL 9.0
+            (80400, 80405),  # MySQL 8.4
             (80300, 80302),  # MySQL 8.3
             (80200, 80202),  # MySQL 8.2
             (80100, 80102),  # MySQL 8.1
-            (80000, 80037),  # MySQL 8.0
+            (80000, 80041),  # MySQL 8.0
             (60000, 60014),  # MySQL 6.0
             (50700, 50745),  # MySQL 5.7
             (50600, 50652),  # MySQL 5.6
@@ -204,8 +208,14 @@ class Fingerprint(GenericFingerprint):
 
             kb.data.has_information_schema = True
 
+            # Determine if it is MySQL >= 9.0.0
+            if inject.checkBooleanExpression("ISNULL(VECTOR_DIM(NULL))"):
+                Backend.setVersion(">= 9.0.0")
+                setDbms("%s 9" % DBMS.MYSQL)
+                self.getBanner()
+
             # Determine if it is MySQL >= 8.0.0
-            if inject.checkBooleanExpression("ISNULL(JSON_STORAGE_FREE(NULL))"):
+            elif inject.checkBooleanExpression("ISNULL(JSON_STORAGE_FREE(NULL))"):
                 Backend.setVersion(">= 8.0.0")
                 setDbms("%s 8" % DBMS.MYSQL)
                 self.getBanner()
